@@ -128,7 +128,7 @@ class MinBwAllocationPlacementTest(manager.NetworkScenarioTest):
         base_segm = \
             CONF.network_feature_enabled.provider_net_base_segmentation_id
 
-        self.prov_network, _, _ = self.create_networks(
+        self.prov_network, _, _ = self.setup_network_subnet_with_router(
             networks_client=self.networks_client,
             routers_client=self.routers_client,
             subnets_client=self.subnets_client,
@@ -146,11 +146,8 @@ class MinBwAllocationPlacementTest(manager.NetworkScenarioTest):
             resources1='%s:%s' % (self.INGRESS_RESOURCE_CLASS,
                                   self.SMALLEST_POSSIBLE_BW))
         if len(alloc_candidates['provider_summaries']) == 0:
-            # Skip if the backend does not support QoS minimum bandwidth
-            # allocation in Placement API
-            raise self.skipException(
-                'No allocation candidates are available for %s:%s' %
-                (self.INGRESS_RESOURCE_CLASS, self.SMALLEST_POSSIBLE_BW))
+            self.fail('No allocation candidates are available for %s:%s' %
+                      (self.INGRESS_RESOURCE_CLASS, self.SMALLEST_POSSIBLE_BW))
 
         # Just to be sure check with impossible high (placement max_int),
         # allocation
@@ -179,6 +176,7 @@ class MinBwAllocationPlacementTest(manager.NetworkScenarioTest):
             consumer)['allocations']
         self.assertGreater(len(allocations), 0)
         bw_resource_in_alloc = False
+        allocation_rp = None
         for rp, resources in allocations.items():
             if self.INGRESS_RESOURCE_CLASS in resources['resources']:
                 self.assertEqual(
@@ -193,9 +191,19 @@ class MinBwAllocationPlacementTest(manager.NetworkScenarioTest):
             # the rp uuid
             for port_id in port_ids:
                 port = self.os_admin.ports_client.show_port(port_id)
-                self.assertEqual(
-                    allocation_rp,
-                    port['port']['binding:profile']['allocation'])
+                port_binding_alloc = port['port']['binding:profile'][
+                    'allocation']
+                # NOTE(gibi): the format of the allocation key depends on the
+                # existence of port-resource-request-groups API extension.
+                # TODO(gibi): drop the else branch once tempest does not need
+                # to support Xena release any more.
+                if utils.is_extension_enabled(
+                        'port-resource-request-groups', 'network'):
+                    self.assertEqual(
+                        {allocation_rp},
+                        set(port_binding_alloc.values()))
+                else:
+                    self.assertEqual(allocation_rp, port_binding_alloc)
 
     @decorators.idempotent_id('78625d92-212c-400e-8695-dd51706858b8')
     @utils.services('compute', 'network')
